@@ -22,7 +22,9 @@
 # # import datetime as dt
 # # import pandas as pd
 # #import fxcmpy and check the imported version
-import fxcmpy as fx
+#import fxcmpy as fx
+#import jgtapy
+
 # import datetime as dt
 # import pandas as pd
 # #fxcmpy.__version__
@@ -36,9 +38,13 @@ import fxcmpy as fx
 # import jgtpy.JGTPDS as pds
 # import jgtpy.JGTCDS as cds
 # import jgtpy.JGTIDS as ids
+#from jgtdotenv import load_dotenv
+#import jgtdotenv
+
 from jgtpy.JGTCore import __version__
 
 from jgtpy.JGTPDS import mk_fn,mk_fullpath,getSubscribed,getPH,getPHByRange,tryConnect
-from jgtpy.JGTCDS import create as createCDS,startSession,stopSession,getLast,getPresentBar,getPresentBarAsList,getLastCompletedBarAsList
+from jgtpy.JGTCDS import create as createCDS,createByRange,createByRange as createCDSByRange,startSession,stopSession,getLast,getPresentBar,getPresentBarAsList,getLastCompletedBarAsList
 # from jgtpy.JGTADS import ads_chart_pto,retrieve_n_chart as ads_retrieve_n_chart
 
+
